# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.23.1~4d0012d',
    built_at='2025-10-13 13:52:09Z',
    sha='4d0012d16c6734612612573549b282c9ad7796ff',
    branch='HEAD',
    tag='v4.23.1',
)
